NAME

Dist::Zilla::Plugin::AutomationPolicy - add an automation policy to a distribution

SYNOPSIS

In the dist.ini:

[AutomationPolicy]
-version    = v0.2.2
description = The automation policy for Foo-Bar-Baz
template    = human_supervised
models      = claude-opus-4-7
models      = claude-opus-4-8

DESCRIPTION

This plugin will create a machine-readable CPAN-META/automation-policy.json file in your distribution, using Dist::AutomationPolicy.

It allows authors to specify the use of automation in generating their modules, and what automated contributions they will accept.

RECENT CHANGES

Changes for version v0.1.1 (2026-05-31)

See the Changes file for more details.

REQUIREMENTS

This module lists the following modules as runtime dependencies:

See the cpanfile file for the full list of prerequisites.

INSTALLATION

The latest version of this module (along with any dependencies) can be installed from CPAN with the cpan tool that is included with Perl:

cpan Dist::Zilla::Plugin::AutomationPolicy

You can also extract the distribution archive and install this module (along with any dependencies):

cpan .

You can also install this module manually using the following commands:

perl Makefile.PL
make
make test
make install

If you are working with the source repository, then it may not have a Makefile.PL file. But you can use the Dist::Zilla tool in anger to build and install this module:

dzil build
dzil test
dzil install --install-command="cpan ."

For more information, see How to install CPAN modules.

SUPPORT

Only the latest version of this module will be supported.

This module requires Perl v5.24 or later, based on the minimum Perl supported by Dist::Zilla.

Reporting Bugs and Submitting Feature Requests

Please report any bugs or feature requests on the bugtracker website https://github.com/robrwo/perl-Dist-Zilla-Plugin-AutomationPolicy/issues

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.

If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker, then see SECURITY.md for instructions how to report security vulnerabilities.

SOURCE

The development version is on github at https://github.com/robrwo/perl-Dist-Zilla-Plugin-AutomationPolicy and may be cloned from https://github.com/robrwo/perl-Dist-Zilla-Plugin-AutomationPolicy.git

AUTHOR

Robert Rothenberg perl@rhizomnic.com

CONTRIBUTOR

Leon Timmermans fawaka@gmail.com

COPYRIGHT AND LICENSE

This software is Copyright (c) 2026 by Robert Rothenberg.

This is free software, licensed under:

The Artistic License 2.0 (GPL Compatible)

SEE ALSO

Metadata v3 Automation Policy